Cassowary
=========

A pure Python implementation of the `Cassowary constraint-solving algorithm`_.
Cassowary is the algorithm that forms the core of the OS X and iOS visual
layout mechanism.

.. _Cassowary constraint-solving algorithm: http://www.cs.washington.edu/research/constraints/cassowary/

Quickstart
----------

Cassowary is compatible with both Python 2 or Python 3. To install Cassowary
in your virtualenv, run::

    $ pip install cassowary

Then, in your Python code, you can create and solve constraint systems. See
:doc:`the documentation <topics/examples>` for examples of what this looks like in
practice.

Documentation
-------------

.. toctree::
   :maxdepth: 2

   topics/theory
   topics/examples
   reference/reference
   internals/contributing
   internals/roadmap
   internals/releases

Community
---------
| Notice: Cassowary is no longer part of the BeeWare suite.
| You can talk to the community through:

 * Tweet Brodderick on Twitter: `@teamskynet_`_


Contributing
------------

If you experience problems with Cassowary, `log them on GitHub`_. If you
want to contribute code, please `fork the code`_ and `submit a pull request`_.


Project Administration
----------------------
| This project was transferred to Brodderick Rodriguez in February 2020. He will continue to oversee its development from here on out.
| Russell Keith-Magee is the original author of this work (2013 - 2019). A big thanks to him for his work! Check out `Russell's GitHub`_.




.. _Russell's GitHub: https://github.com/freakboy3742
.. _@teamskynet_: https://twitter.com/teamskynet_
.. _homepage: http://brodderick.com/projects/cassowary
.. _Read The Docs: https://cassowary.readthedocs.io

.. _log them on Github: https://github.com/brodderickrodriguez/cassowary/issues
.. _fork the code: https://github.com/brodderickrodriguez/cassowary
.. _submit a pull request: https://github.com/brodderickrodriguez/cassowary/pulls


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
